@@ -20,12 +20,11 @@
  * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
  * 
  */
-#include "../include/hoel.h"
-#include "../include/h-private.h"
+#include "hoel.h"
+#include "h-private.h"
 
 #ifdef _HOEL_MARIADB
 /* MariaDB library Includes */
-#include <my_global.h>
 #include <mysql.h>
 #include <string.h>
 
@@ -70,11 +69,13 @@ struct _h_connection * h_connect_mariadb(const char * host, const char * user, c
     }
     if (mysql_library_init(0, NULL, NULL)) {
       y_log_message(Y_LOG_LEVEL_ERROR, "mysql_library_init error, aborting");
+      free(conn);
       return NULL;
     }
     ((struct _h_mariadb *)conn->connection)->db_handle = mysql_init(NULL);
     if (((struct _h_mariadb *)conn->connection)->db_handle == NULL) {
       y_log_message(Y_LOG_LEVEL_ERROR, "mysql_init error, aborting");
+      free(conn);
       return NULL;
     }
     if (mysql_real_connect(((struct _h_mariadb *)conn->connection)->db_handle,
@@ -82,6 +83,7 @@ struct _h_connection * h_connect_mariadb(const char * host, const char * user, c
       y_log_message(Y_LOG_LEVEL_ERROR, "Error connecting to mariadb database %s", db);
       y_log_message(Y_LOG_LEVEL_DEBUG, "Error message: \"%s\"", mysql_error(((struct _h_mariadb *)conn->connection)->db_handle));
       mysql_close(((struct _h_mariadb *)conn->connection)->db_handle);
+      free(conn);
       return NULL;
     } else {
       /* Set MYSQL_OPT_RECONNECT to true to reconnect automatically when connection is closed by the server (to avoid CR_SERVER_GONE_ERROR) */
